package br.com.evologica.mvp.ui.base;

import java.net.ConnectException;
import java.net.NoRouteToHostException;
import java.net.SocketTimeoutException;
import java.net.UnknownHostException;

import javax.inject.Inject;

import br.com.evologica.curio.exception.UCImplNotFoundException;
import br.com.evologica.curio.exception.UCSessionNotFoundException;
import br.com.evologica.mvp.data.DataManager;
import br.com.evologica.mvp.utils.rx.SchedulerProvider;
import io.reactivex.disposables.CompositeDisposable;

public class BasePresenter<V extends MvpView> implements MvpPresenter<V> {

    private V mvpView;

    private final DataManager dataManager;
    private final CompositeDisposable compositeDisposable;
    private final SchedulerProvider schedulerProvider;

    @Inject
    public BasePresenter(DataManager mDataManager, CompositeDisposable mCompositeDisposable, SchedulerProvider schedulerProvider) {
        this.dataManager = mDataManager;
        this.compositeDisposable = mCompositeDisposable;
        this.schedulerProvider = schedulerProvider;
    }

    public V getMvpView() {
        return mvpView;
    }

    @Override
    public void onAttach(V mvpView) {
        this.mvpView = mvpView;
    }

    @Override
    public void onDetach() {
        mvpView = null;
        compositeDisposable.clear();
    }

    @Override
    public void handleError(Throwable err) {
        if(err instanceof UCImplNotFoundException) {
            if (isViewAttached())
                getMvpView().onError("Não é possível realizar essa operação nesta versão do serviço");
        } else if(err instanceof UCSessionNotFoundException){
            getDataManager().closeSession();
            if(isViewAttached())
                getMvpView().sessionFinished();
        }else if(err instanceof UnknownHostException ||
                err instanceof ConnectException ||
                err instanceof SocketTimeoutException ||
                err instanceof NoRouteToHostException) {
            if (isViewAttached()) {
                //getMvpView().onError(R.string.connect_exception_message);
            }
        } else {
            if(isViewAttached()) {
                getMvpView().onError(err.getMessage());
            }
        }
    }

    public boolean isViewAttached() {
        return mvpView != null;
    }

    public DataManager getDataManager() {
        return dataManager;
    }

    public CompositeDisposable getCompositeDisposable() {
        return compositeDisposable;
    }

    public SchedulerProvider getSchedulerProvider() {
        return schedulerProvider;
    }

}
